pub struct Block {Show 21 fields
pub base_fee_per_gas: Option<Nat256>,
pub number: Nat256,
pub difficulty: Option<Nat256>,
pub extra_data: Hex,
pub gas_limit: Nat256,
pub gas_used: Nat256,
pub hash: Hex32,
pub logs_bloom: Hex256,
pub miner: Hex20,
pub mix_hash: Hex32,
pub nonce: Nat256,
pub parent_hash: Hex32,
pub receipts_root: Hex32,
pub sha3_uncles: Hex32,
pub size: Nat256,
pub state_root: Hex32,
pub timestamp: Nat256,
pub total_difficulty: Option<Nat256>,
pub transactions: Vec<Hex32>,
pub transactions_root: Option<Hex32>,
pub uncles: Vec<Hex32>,
}Fields
base_fee_per_gas: Option<Nat256>Base fee per gas Only included for blocks after the London Upgrade / EIP-1559.
number: Nat256Block number
difficulty: Option<Nat256>Difficulty
extra_data: HexExtra data
gas_limit: Nat256Maximum gas allowed in this block
gas_used: Nat256Gas used by all transactions in this block
hash: Hex32Block hash
logs_bloom: Hex256Bloom filter for the logs.
miner: Hex20Miner
mix_hash: Hex32Mix hash
nonce: Nat256Nonce
parent_hash: Hex32Parent block hash
receipts_root: Hex32Receipts root
sha3_uncles: Hex32Ommers hash
size: Nat256Block size
state_root: Hex32State root
timestamp: Nat256Timestamp
total_difficulty: Option<Nat256>Total difficulty is the sum of all difficulty values up to and including this block.
Note: this field was removed from the official JSON-RPC specification in https://github.com/ethereum/execution-apis/pull/570 and may no longer be served by providers.
transactions: Vec<Hex32>Transaction hashes
transactions_root: Option<Hex32>Transactions root
uncles: Vec<Hex32>Uncles